<?php
/**
 * @file
 * Plugins are described by creating a $plugin array which will
 * be used by the system that includes the file.
 */
$plugin = array(
  'title' => t('Term: no children'),
  'description' => t('Controls access by term having no children'),
  'callback' => 'opentastings_wine_term_no_children_ctools_access_check',
  'default' => array('no_children' => ''),
  'settings form' => 'opentastings_wine_term_no_children_ctools_settings',
  'summary' => 'opentastings_wine_term_no_children_ctools_summary',
  'required context' => new ctools_context_required(t('Term'), array('taxonomy_term', 'terms')),
);

/**
 * Custom callback defined by 'callback' in the $plugin array.
 *
 * Check for access.
 */
function opentastings_wine_term_no_children_ctools_access_check($conf, $context) {
  // If for some unknown reason that $context isn't set, we just want to be sure.
  if (empty($context) || empty($context->data)  || !isset($context->data->tid) || !isset($context->data->vid)) {
    return FALSE;
  }

  $ch = taxonomy_get_children($context->data->tid, $context->data->vid);

  // If children do not show.
  if (count($ch)) {
    return FALSE;
  }
  return TRUE;
}

/**
 * Settings form for the 'term_no_children' access plugin.
 */
function opentastings_wine_term_no_children_ctools_settings($form, &$form_state, $conf) {
  $form['settings']['no_children'] = array(
    '#type' => 'textfield',
    '#title' => t('Description'),
    '#description' => t('The pane will only be visible if the description of the term is the same as set in this field'),
    '#default_value' => $conf['no_children'],
  );
  return $form;
}

/**
 * Provide a summary description based upon the children.
 */
function opentastings_wine_term_no_children_ctools_summary($conf, $context) {
  return t('Term without children');
}



